@@ -1,6 +1,38 @@
 from bs4 import BeautifulSoup
 import lxml, os, copy, pandas, time, datetime, requests, sys
 
+class SSTime:
+    
+    month_table = [ 
+        "ja", "f", "m", "a", "M", "j", "J", "A", "s", "o", "n", "d"     
+    ]
+
+    def help():
+        
+        print("SSTime: ")
+        
+        print("\t[1] SSTime.name(basename = \"\", extension = \"\")\n")
+
+    def name(basename = "", extension = ""):
+        
+        CT = datetime.datetime.now()
+        
+        year = int(CT.strftime("%y"))
+        
+        month = int(CT.strftime("%m"))
+        
+        day = int(CT.strftime("%d"))
+        
+        hour = int(CT.strftime("%H"))
+        
+        minute = int(CT.strftime("%M"))
+        
+        second = int(CT.strftime("%S"))
+        
+        return (
+            f"{basename}_D-{SSTime.month_table[month - 1]}{day}20{year}_T-{hour}{minute}{second}{extension}"
+        )
+
 class SSParse:
     
     def help():
@@ -495,4 +527,9 @@ SSSave.help()
 file = SSSave("temp.json", "link", progress_bar = True, overwrite = False)
 
 file.download()
+"""
+"""
+SSTime.help()
+timenow = SSTime.name()
+print(timenow)
 """
\ No newline at end of file
